FromVoxSession

Trait FromVoxSession 

pub trait FromVoxSession {
    const SERVICE_NAME: &'static str;

    // Required method
    fn from_vox_session(
        caller: Caller,
        session_handle: Option<SessionHandle>,
    ) -> Self;
}
Trait for constructing a typed client from a vox session.

Generated *Client types implement this to receive both the caller and an optional session handle. Root connections pass Some(handle); virtual connections pass None.

Required Associated Constants

const SERVICE_NAME: &'static str

The service name for this client, used for automatic vox-service metadata. Generated clients return Some("ServiceName"). NoopClient returns None.

Required Methods

fn from_vox_session( caller: Caller, session_handle: Option<SessionHandle>, ) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors