pub struct MetadataFlags(/* private fields */);Expand description
Metadata entry flags.
Flags control metadata handling behavior.
Implementations
Sourceimpl MetadataFlags
impl MetadataFlags
Sourcepub const NONE: MetadataFlags
pub const NONE: MetadataFlags
No special handling.
Sourcepub const SENSITIVE: MetadataFlags
pub const SENSITIVE: MetadataFlags
Value MUST NOT be logged, traced, or included in error messages.
Sourcepub const NO_PROPAGATE: MetadataFlags
pub const NO_PROPAGATE: MetadataFlags
Value MUST NOT be forwarded to downstream calls.
Sourcepub fn contains(self, other: MetadataFlags) -> bool
pub fn contains(self, other: MetadataFlags) -> bool
Returns true if all flags in other are set in self.